@@ -10,14 +10,14 @@ from ...imports import *
 __all__ = ["to_text"]
 
 
-def to_text(rainbow, filepath, overwrite=True, group_by="wavelength"):
+def to_text(self, filepath, overwrite=True, group_by="wavelength"):
     """
     Write a Rainbow to a file in the text format.
 
     Parameters
     ----------
 
-    rainbow : Rainbow
+    self : Rainbow
         The object to be saved.
 
     filepath : str
@@ -25,18 +25,16 @@ def to_text(rainbow, filepath, overwrite=True, group_by="wavelength"):
     """
 
     # a 1D array of wavelengths (with astropy units of length)
-    the_1D_array_of_wavelengths = rainbow.wavelike["wavelength"]
+    the_1D_array_of_wavelengths = self.wavelike["wavelength"]
 
     # a 1D array of times (with astropy units of time)
-    the_1D_array_of_times = rainbow.timelike["time"]
+    the_1D_array_of_times = self.timelike["time"]
 
     # a 2D (row = wavelength, col = array of fluxes
-    the_2D_array_of_fluxes = rainbow.fluxlike["flux"]
+    the_2D_array_of_fluxes = self.fluxlike["flux"]
 
     # write out your file, however you like
-    w, t = np.meshgrid(
-        rainbow.wavelength.to("micron"), rainbow.time.to("day"), indexing="ij"
-    )
+    w, t = np.meshgrid(self.wavelength.to("micron"), self.time.to("day"), indexing="ij")
 
     def make_into_columns(x):
         if group_by == "wavelength":
@@ -47,19 +45,19 @@ def to_text(rainbow, filepath, overwrite=True, group_by="wavelength"):
     # create a table
     table = Table(
         dict(wavelength=make_into_columns(w), time=make_into_columns(t)),
-        meta=rainbow.metadata,
+        meta=self.metadata,
     )
-    table["flux"] = make_into_columns(rainbow.flux)
+    table["flux"] = make_into_columns(self.flux)
     try:
-        table["uncertainty"] = make_into_columns(rainbow.uncertainty)
+        table["uncertainty"] = make_into_columns(self.uncertainty)
     except KeyError:
         pass
 
-    other_keys = list(rainbow.fluxlike.keys())
+    other_keys = list(self.fluxlike.keys())
     other_keys.remove("flux")
     other_keys.remove("uncertainty")
 
     for k in other_keys:
-        table[k] = make_into_columns(rainbow.fluxlike[k])
+        table[k] = make_into_columns(self.fluxlike[k])
 
     table.write(filepath, format="ascii.ecsv", overwrite=overwrite)
